hephae!() { /* proc-macro */ }Expand description
The hephae! { ... } procedural macro for specifying Hephae plugins.
// You can define these plugin attributes in any order, as long as you only define it either zero or one times.
hephae! {
// `atlas`: Requires the `"atlas"` feature, and does not accept any type arguments.
atlas,
// `locale`: Requires the `"locale"` feature, optionally accepts `(ArgConf, TargetConf)` type arguments.
locale: ((MyLocaleArg1, MyLocaleArg2, ..), (MyTarget1, MyTarget2, ..)),
// `render`: Always available, optionally accepts `(VertexConf, DrawerConf)` type arguments.
render: ((MyVertex1, MyVertex2, ..), (MyDrawer1, MyDrawer2, ..)),
// `text`: Requires the `"text"` feature, and does not accept any type arguments.
text,
// `ui`: Requires the `"ui"` feature, optionally accepts `(MeasureConf, RootConf)` type arguments.
ui: ((MyMeasurer1, MyMeasurer2, ..), (MyRoot1, MyRoot2, ..)),
// You can also tell the macro to include every Hephae features via the feature flags with their default settings.
// Note that this `..` syntax must appear at the very last.
..
}